@@ -416,6 +416,7 @@ if(!Array.indexOf) {
         function on_template_key_changed(){
             var input_element = this;
             var new_template = this.value;
+            var form_element = $(input_element).parents('form');
 
             if(current_template==new_template)
                 // Selected template did not change
@@ -444,19 +445,24 @@ if(!Array.indexOf) {
             jConfirm(msg, CHANGE_TEMPLATE_MESSAGES[0], function(ret) {
                 if(ret) {
                     for(var i=0; i<not_in_new.length; i++) {
-                        var items = $('#'+not_in_new[i]+'_body div.order-machine').children();
-                        // FIXME: this moves all soon-to-be-homeless items
-                        // to the first region, but that region is quite likely
-                        // not in the new template.
-                        move_item(0, items);
+                        var body = $('#' + not_in_new[i] + '_body'),
+                            machine = body.find('.order-machine'),
+                            inputs = machine.find('input[name$=region]');
+
+                        inputs.val(new_regions[0]);
                     }
 
                     input_element.checked = true;
 
-                    $('form').append('<input type="hidden" name="_continue" value="1" />').submit();
+                    form_element.append('<input type="hidden" name="_continue" value="1" />');
+                    /* Simulate a click on the save button instead of form.submit(), so
+                       that the submit handlers from FilteredSelectMultiple get
+                       invoked. See Issue #372 */
+                    $('#page_form input[type=submit][name=_save]').click();
+
                 } else {
                     $("div#popup_bg").remove();
-                    $(input_element).val($(input_element).data('original_value')); // Restore original value
+                    form_element.val($(input_element).data('original_value')); // Restore original value
                 }
             });
 
@@ -509,7 +515,7 @@ if(!Array.indexOf) {
         $(".order-machine").sortable({
             handle: '.handle',
             helper: function(event, ui){
-                var h2 = $("<h2>").html($(ui.item).find('span.modname').html());
+                var h2 = $("<h2>").html($(ui).find('span.modname').html());
                 return $("<fieldset>").addClass("helper module").append(h2);
             },
             placeholder: 'highlight',
